==> openlit-1.33.11.tar.gz: openlit-1.33.11/src/openlit/instrumentation/openai/__init__.py <==
# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
"""Initializer of Auto Instrumentation of OpenAI Functions"""
from typing import Collection
import importlib.metadata
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from wrapt import wrap_function_wrapper

from openlit.instrumentation.openai.openai import chat_completions, embedding
from openlit.instrumentation.openai.openai import image_generate, image_variatons, audio_create
from openlit.instrumentation.openai.async_openai import async_chat_completions, async_embedding
from openlit.instrumentation.openai.async_openai import async_image_generate, async_image_variatons
from openlit.instrumentation.openai.async_openai import async_audio_create

_instruments = ("openai >= 1.1.1",)

class OpenAIInstrumentor(BaseInstrumentor):
    """An instrumentor for OpenAI's client library."""

    def instrumentation_dependencies(self) -> Collection[str]:
        return _instruments

    def _instrument(self, **kwargs):
        application_name = kwargs.get("application_name")
        environment = kwargs.get("environment")
        tracer = kwargs.get("tracer")
        metrics = kwargs.get("metrics_dict")
        pricing_info = kwargs.get("pricing_info")
        capture_message_content = kwargs.get("capture_message_content")
        disable_metrics = kwargs.get("disable_metrics")
        version = importlib.metadata.version("openai")

        wrap_function_wrapper(
            "openai.resources.chat.completions",  
            "Completions.create",  
            chat_completions(version, environment, application_name,
                         tracer, pricing_info, capture_message_content,
                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.chat.completions",  
            "AsyncCompletions.create",  
            async_chat_completions(version, environment, application_name,
                               tracer, pricing_info, capture_message_content,
                               metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "Images.generate",  
            image_generate(version, environment, application_name,
                                   tracer, pricing_info, capture_message_content,
                                   metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "AsyncImages.generate",  
            async_image_generate(version, environment, application_name,
                                         tracer, pricing_info, capture_message_content,
                                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.embeddings",  
            "Embeddings.create",  
            embedding(version, environment, application_name,
                              tracer, pricing_info, capture_message_content,
                              metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.embeddings",  
            "AsyncEmbeddings.create",  
            async_embedding(version, environment, application_name,
                                    tracer, pricing_info, capture_message_content,
                                    metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "Images.create_variation",  
            image_variatons(version,
                            environment, application_name,
                            tracer, pricing_info, capture_message_content,
                            metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "AsyncImages.create_variation",  
            async_image_variatons(version,
                                  environment, application_name,
                                  tracer, pricing_info, capture_message_content,
                                  metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.audio.speech",  
            "Speech.create",  
            audio_create(version, environment, application_name,
                         tracer, pricing_info, capture_message_content,
                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.audio.speech",  
            "AsyncSpeech.create",  
            async_audio_create(version, environment, application_name,
                               tracer, pricing_info, capture_message_content,
                               metrics, disable_metrics),
        )

    @staticmethod
    def _uninstrument(self, **kwargs):
        pass

==> openlit-1.34.5.tar.gz: openlit-1.34.5/src/openlit/instrumentation/openai/__init__.py <==
# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
"""Initializer of Auto Instrumentation of OpenAI Functions"""
from typing import Collection
import importlib.metadata
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from wrapt import wrap_function_wrapper

from openlit.instrumentation.openai.openai import chat_completions, embedding, responses, chat_completions_parse
from openlit.instrumentation.openai.openai import image_generate, image_variatons, audio_create
from openlit.instrumentation.openai.async_openai import (async_chat_completions, async_embedding,
                                                         async_chat_completions_parse)
from openlit.instrumentation.openai.async_openai import async_image_generate, async_image_variatons
from openlit.instrumentation.openai.async_openai import async_audio_create, async_responses

_instruments = ("openai >= 1.1.1",)

class OpenAIInstrumentor(BaseInstrumentor):
    """An instrumentor for OpenAI's client library."""

    def instrumentation_dependencies(self) -> Collection[str]:
        return _instruments

    def _instrument(self, **kwargs):
        application_name = kwargs.get("application_name")
        environment = kwargs.get("environment")
        tracer = kwargs.get("tracer")
        metrics = kwargs.get("metrics_dict")
        pricing_info = kwargs.get("pricing_info")
        capture_message_content = kwargs.get("capture_message_content")
        disable_metrics = kwargs.get("disable_metrics")
        version = importlib.metadata.version("openai")

        wrap_function_wrapper(
            "openai.resources.chat.completions",  
            "Completions.create",  
            chat_completions(version, environment, application_name,
                         tracer, pricing_info, capture_message_content,
                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.chat.completions",  
            "AsyncCompletions.create",  
            async_chat_completions(version, environment, application_name,
                               tracer, pricing_info, capture_message_content,
                               metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.responses.responses",  
            "Responses.create",  
            responses(version, environment, application_name,
                         tracer, pricing_info, capture_message_content,
                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.responses.responses",  
            "AsyncResponses.create",  
            async_responses(version, environment, application_name,
                         tracer, pricing_info, capture_message_content,
                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "Images.generate",  
            image_generate(version, environment, application_name,
                                   tracer, pricing_info, capture_message_content,
                                   metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "AsyncImages.generate",  
            async_image_generate(version, environment, application_name,
                                         tracer, pricing_info, capture_message_content,
                                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.embeddings",  
            "Embeddings.create",  
            embedding(version, environment, application_name,
                              tracer, pricing_info, capture_message_content,
                              metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.embeddings",  
            "AsyncEmbeddings.create",  
            async_embedding(version, environment, application_name,
                                    tracer, pricing_info, capture_message_content,
                                    metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "Images.create_variation",  
            image_variatons(version,
                            environment, application_name,
                            tracer, pricing_info, capture_message_content,
                            metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.images",  
            "AsyncImages.create_variation",  
            async_image_variatons(version,
                                  environment, application_name,
                                  tracer, pricing_info, capture_message_content,
                                  metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.audio.speech",  
            "Speech.create",  
            audio_create(version, environment, application_name,
                         tracer, pricing_info, capture_message_content,
                         metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.audio.speech",  
            "AsyncSpeech.create",  
            async_audio_create(version, environment, application_name,
                               tracer, pricing_info, capture_message_content,
                               metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.beta.chat.completions",
            "Completions.parse",
            chat_completions_parse(version, environment, application_name, tracer, pricing_info,
                                   capture_message_content, metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "openai.resources.beta.chat.completions",
            "AsyncCompletions.parse",
            async_chat_completions_parse(version, environment, application_name, tracer, pricing_info,
                                         capture_message_content, metrics, disable_metrics),
        )

    @staticmethod
    def _uninstrument(self, **kwargs):
        pass
